Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: pkg/analyzer/lib/src/summary/summarize_ast.dart

Issue 2508343002: Rename UnlinkedConst -> UnlinkedExpr (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer/lib/src/summary/summarize_ast.dart
diff --git a/pkg/analyzer/lib/src/summary/summarize_ast.dart b/pkg/analyzer/lib/src/summary/summarize_ast.dart
index b81fe880eae2a20c4dc997f82c030105c9f29571..5d357832aababeccf536b5a4cbd7f2fd59157484 100644
--- a/pkg/analyzer/lib/src/summary/summarize_ast.dart
+++ b/pkg/analyzer/lib/src/summary/summarize_ast.dart
@@ -331,7 +331,7 @@ class _SummarizeAstVisitor extends RecursiveAstVisitor {
* If the library has a library directive, the annotations for it (if any).
* Otherwise `null`.
*/
- List<UnlinkedConst> libraryAnnotations = const <UnlinkedConstBuilder>[];
+ List<UnlinkedExpr> libraryAnnotations = const <UnlinkedExprBuilder>[];
/**
* The number of slot ids which have been assigned to this compilation unit.
@@ -407,10 +407,10 @@ class _SummarizeAstVisitor extends RecursiveAstVisitor {
* Serialize the given list of [annotations]. If there are no annotations,
* the empty list is returned.
*/
- List<UnlinkedConstBuilder> serializeAnnotations(
+ List<UnlinkedExprBuilder> serializeAnnotations(
NodeList<Annotation> annotations) {
if (annotations == null || annotations.isEmpty) {
- return const <UnlinkedConstBuilder>[];
+ return const <UnlinkedExprBuilder>[];
}
return annotations.map((Annotation a) {
// Closures can't appear inside annotations, so we don't need a
@@ -546,9 +546,9 @@ class _SummarizeAstVisitor extends RecursiveAstVisitor {
}
/**
* Serialize the given [expression], creating an [UnlinkedConstBuilder].
*/
- UnlinkedConstBuilder serializeConstExpr(
+ UnlinkedExprBuilder serializeConstExpr(
Map<int, int> localClosureIndexMap, Expression expression,
[Set<String> parameterNames]) {
_ConstExprSerializer serializer =
@@ -546,9 +546,9 @@ class _SummarizeAstVisitor extends RecursiveAstVisitor {
}
/**
- * Serialize the given [expression], creating an [UnlinkedConstBuilder].
+ * Serialize the given [expression], creating an [UnlinkedExprBuilder].
*/
« no previous file with comments | « pkg/analyzer/lib/src/summary/resynthesize.dart ('k') | pkg/analyzer/lib/src/summary/summarize_const_expr.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698